﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UPWpfAgeev.Classes;
using UPWpfAgeev.Model;

namespace UPWpfAgeev.ViewModels
{
    internal class ListProduct : INotifyPropertyChanged
    {
        // fields
        List<Product> _allProducts;
        List<Product> _viewProduct;
        int _sizeViewProducts = 0;
        string _textSearch = string.Empty;

        // handler of event
        public event PropertyChangedEventHandler PropertyChanged;

        // ctor
        public ListProduct()
        {
            _allProducts = BaseConnection.MyDataBase.Product.ToList();
            _viewProduct = _allProducts;
            _sizeViewProducts = _viewProduct.Count;
            priceID = 0;
            discountId = 0;

        }

        void SelectFilters()
        {
            ViewProduct = _allProducts;

            if (TextSearch != string.Empty)
            {
                ViewProduct = ViewProduct.Where(x => x.ProductName.ToLower().Contains(TextSearch.ToLower())).ToList();
            }

            if ( PriceId != 0) // Фильтр по возрастанию и убыванию цены
            {
                switch (PriceId)
                {
                    case 1:
                        ViewProduct = ViewProduct.OrderBy( c => c.ActualPrice).ToList();
                        break;

                    case 2:
                        ViewProduct = ViewProduct.OrderByDescending( c => c.ActualPrice).ToList();
                        break;
                    default:
                        break;
                }
            }

            if (DiscountId != 0)
            {
                switch (DiscountId)
                { 
                    case 1:
                        ViewProduct = ViewProduct.Where(x => x.DiscountPercentage < 10.0).ToList();
                        break;
                    case 2:
                        ViewProduct = ViewProduct.Where(x => x.DiscountPercentage < 15.0 && x.DiscountPercentage > 10.0).ToList();
                        break;

                    case 3:
                        ViewProduct = ViewProduct.Where(x => x.DiscountPercentage >= 15.0).ToList();
                        break;
                
                }
            }

        }


        // property
        public List<Product> ViewProduct { 
            get => _viewProduct; 
            set { _viewProduct = value; PropertyChanged.Invoke(this, new PropertyChangedEventArgs(nameof(ViewProduct))); } }

        public string TextSearch { 
            get => _textSearch;
            set { _textSearch = value; PropertyChanged.Invoke(this, new PropertyChangedEventArgs(nameof(TextSearch))); SelectFilters();  } }


        public int SizeViewProduct {
            get => _sizeViewProducts;
            set { _sizeViewProducts = value; PropertyChanged.Invoke(this, new PropertyChangedEventArgs(nameof(SizeViewProduct))); } }


        // filters
        string[] priceSort = new string[] { "По умолчанию", "По возрастанию", "По убыванию" };
        public string[] PriceSort { get => priceSort; set => priceSort = value; }

        int priceID;
        public int PriceId { 
            get => priceID; 
            set { priceID = value; PropertyChanged.Invoke(this, new PropertyChangedEventArgs(nameof(PriceId))); SelectFilters();  } }


        string[] discountPrice = new string[] { "Все диапазоны", "0-9", "10-14", "15 и более" };
        public string[] DiscountPrice { get => discountPrice; set => discountPrice = value; }

        int discountId;
        public int DiscountId { 
            get => discountId;
            set {discountId = value; PropertyChanged.Invoke(this, new PropertyChangedEventArgs(nameof(DiscountId))); SelectFilters(); } }



    }
}
